@@ -29,10 +29,10 @@ def on_predicate(wait_gen: _WaitGenerator,
                  *,
                  max_tries: Optional[_MaybeCallable[int]] = None,
                  max_time: Optional[_MaybeCallable[float]] = None,
-                 jitter: _Jitterer = full_jitter,
-                 on_success: Union[_Handler, Iterable[_Handler]] = None,
-                 on_backoff: Union[_Handler, Iterable[_Handler]] = None,
-                 on_giveup: Union[_Handler, Iterable[_Handler]] = None,
+                 jitter: Union[_Jitterer, None] = full_jitter,
+                 on_success: Union[_Handler, Iterable[_Handler], None] = None,
+                 on_backoff: Union[_Handler, Iterable[_Handler], None] = None,
+                 on_giveup: Union[_Handler, Iterable[_Handler], None] = None,
                  logger: _MaybeLogger = 'backoff',
                  backoff_log_level: int = logging.INFO,
                  giveup_log_level: int = logging.ERROR,
@@ -125,11 +125,11 @@ def on_exception(wait_gen: _WaitGenerator,
                  *,
                  max_tries: Optional[_MaybeCallable[int]] = None,
                  max_time: Optional[_MaybeCallable[float]] = None,
-                 jitter: _Jitterer = full_jitter,
+                 jitter: Union[_Jitterer, None] = full_jitter,
                  giveup: _Predicate[Exception] = lambda e: False,
-                 on_success: Union[_Handler, Iterable[_Handler]] = None,
-                 on_backoff: Union[_Handler, Iterable[_Handler]] = None,
-                 on_giveup: Union[_Handler, Iterable[_Handler]] = None,
+                 on_success: Union[_Handler, Iterable[_Handler], None] = None,
+                 on_backoff: Union[_Handler, Iterable[_Handler], None] = None,
+                 on_giveup: Union[_Handler, Iterable[_Handler], None] = None,
                  raise_on_giveup: bool = True,
                  logger: _MaybeLogger = 'backoff',
                  backoff_log_level: int = logging.INFO,
