@@ -3,7 +3,7 @@
 import random
 
 
-def random_jitter(value):
+def random_jitter(value: float) -> float:
     """Jitter the value a random number of milliseconds.
 
     This adds up to 1 second of additional time to the original value.
@@ -15,7 +15,7 @@ def random_jitter(value):
     return value + random.random()
 
 
-def full_jitter(value):
+def full_jitter(value: float) -> float:
     """Jitter the value across the full range (0 to value).
 
     This corresponds to the "Full Jitter" algorithm specified in the
